@@ -978,9 +978,9 @@ class Askdata(SignUp):
     def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=True, dataset_name="", locale="en", skip_import_values=False):
 
         df_copy = df.copy()
-        for col in df_copy.columns:
+        '''for col in df_copy.columns:
             if (df_copy[col].dtypes == "datetime64[ns]"):
-                df_copy[col] = df_copy[col].astype("str").replace("NaT", None)
+                df_copy[col] = df_copy[col].astype("str").replace("NaT", None)'''
 
         #df = df.where(pd.notnull(df), None)
         df_copy = self.normalize_columns(df)
